
/*
 * Written by Scott Auge scott_auge@yahoo.com sauge@amduus.com
 * Copyright (c) 2001 Amduus Information Works, Inc.  www.amduus.com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Amduus Information Works
 *      Inc. and its contributors.
 * 4. Neither the name of Amduus Information Works, Inc. nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY AMDUUS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AMDUUS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */


/* AddTicketNote.p
 * Written by Scott Auge
 *
 * Add a ticket note to the ticket specified.
 */

DEF VAR RCSVersion AS CHARACTER INIT "$Header: /home/appl/srvexp/src/api/records/RCS/AddTicketNote.p,v 1.3 2001/12/05 03:23:54 sauge Exp $" NO-UNDO.

DEF INPUT PARAMETER pTicketSeq      AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pNoteText       AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER pTicketNoteSeq AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER pError         AS CHARACTER NO-UNDO.

DEF VAR pNoteSeq   AS CHARACTER NO-UNDO.
DEF VAR lLastOrder AS INTEGER NO-UNDO.

DEF BUFFER bTicketNote FOR TicketNote.

{api/Error.inc}
{MakeID2.i}
{Log.i}

{LogIt.i '"Begin Program"'}

/* Create a note.  The notes table is for general purpose use for later */
/* functionallity to be added.  The TicketNotes table is used to store  */
/* information specific to tickets.                                     */

RUN api/records/CreateNote.p (INPUT pNoteText,
                           INPUT "C",
                           OUTPUT pNoteSeq,
                           OUTPUT pError).

IF pError <> {&NOERROR} THEN RETURN.

/* Create the TicketNote and relate it to the ticket as well who made the */
/* thing.  Note that the login is not part of the note.  This should be   */
/* part of the note text.  If parsing is needed to seperate out data      */
/* about the note, then do so on the note text.                           */

CREATE TicketNote.

ASSIGN TicketNote.TicketNoteSeq = MakeID2 (10).

ASSIGN 
TicketNote.NoteSeq   = pNoteSeq
TicketNote.TicketSeq = pTicketSeq.

/* Tag this onto the end of the sequence of notes for the ticket. */

FOR EACH bTicketNote NO-LOCK
BY Order:

  ASSIGN lLastOrder = bTicketNote.Order.

END.

ASSIGN TicketNote.Order = lLastOrder + 1.

ASSIGN pError = {&NOERROR}.
