
/*
 * Written by Scott Auge scott_auge@yahoo.com sauge@amduus.com
 * Copyright (c) 2001 Amduus Information Works, Inc.  www.amduus.com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Amduus Information Works
 *      Inc. and its contributors.
 * 4. Neither the name of Amduus Information Works, Inc. nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY AMDUUS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AMDUUS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */


/* CreateTicketStatus.p
 *
 * Written by Scott Auge
 */

DEF VAR RCSVersion AS CHARACTER INIT "$Header: /home/appl/srvexp/src/api/records/RCS/CreateTicketStatus.p,v 1.3 2001/12/15 20:39:11 sauge Exp $" NO-UNDO.

DEF INPUT PARAMETER pName             AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pIsDefault        AS LOGICAL NO-UNDO.
DEF INPUT PARAMETER pHideTicket       AS LOGICAL NO-UNDO.
DEF INPUT PARAMETER pHideFromExternal AS LOGICAL NO-UNDO.
DEF INPUT PARAMETER pProblemTypeSeq    AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER pTicketStatusSeq AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER pError           AS CHARACTER NO-UNDO.

{api/Error.inc}
{MakeID2.i}
{Log.i}

{LogIt.i '"Begin Program"'}

/* Make sure we dont have a ticket status with this name */

IF CAN-FIND (TicketStatus WHERE TicketStatus.Name = pName 
                            AND TicketStatus.ProblemTypeSeq = pProblemTypeSeq 
                            AND TicketStatus.Active = YES)
THEN DO:

  ASSIGN pError = {&DATAEXISTS}.
  RETURN.

END.

/* Make sure we have a valid key to a ProblemType record */

IF NOT CAN-FIND (ProblemType WHERE ProblemType.ProblemTypeSeq = pProblemTypeSeq)
THEN DO:

  ASSIGN pError = {&NORECORD}.
  RETURN.

END.

/* If this record is to be the default status for this ProblemType */
/* make sure that the other records that might be default are not. */

IF pIsDefault THEN 
  FOR EACH TicketStatus EXCLUSIVE-LOCK
  WHERE TicketStatus.ProblemType = pProblemTypeSeq
    AND TicketStatus.IsDefault = YES:

    ASSIGN TicketStatus.IsDefault = NO.

  END.

FIND TicketStatus EXCLUSIVE-LOCK
WHERE TicketStatus.Name = pName
  and TicketStatus.ProblemType = pProblemTypeSeq
NO-ERROR.

/* Create the record */

IF NOT AVAILABLE TicketStatus THEN DO:

  CREATE TicketStatus.
  TicketStatus.TicketStatusSeq = MakeID2(10).

END.

ASSIGN
TicketStatus.ProblemTypeSeq = pProblemTypeSeq
TicketStatus.Name = pName
TicketStatus.IsDefault = pIsDefault
TicketStatus.HideTicket = pHideTicket
TicketStatus.HideFromExternal = pHideFromExternal
TicketStatus.Active = YES.

ASSIGN pError = {&NOERROR}.

