
/*
 * Written by Scott Auge scott_auge@yahoo.com sauge@amduus.com
 * Copyright (c) 2001 Amduus Information Works, Inc.  www.amduus.com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Amduus Information Works
 *      Inc. and its contributors.
 * 4. Neither the name of Amduus Information Works, Inc. nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY AMDUUS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AMDUUS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

/* Program determines who to assign the ticket to.  It does not manipulate */
/* any data records.                                                       */

DEF VAR RCSVersion AS CHARACTER INIT "$Header: /home/appl/srvexp/src/api/ticket/RCS/AssignTicket.p,v 1.5 2001/12/15 20:39:10 sauge Exp $" NO-UNDO.

DEF INPUT PARAMETER pTicketSeq      AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER pEmployeeSeq   AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER pError         AS CHARACTER NO-UNDO.

DEF VAR lError           AS CHARACTER NO-UNDO.
DEF VAR lListPositionSeq AS CHARACTER NO-UNDO.
DEF VAR lListEmployeeSeq AS CHARACTER NO-UNDO.

{api/Error.inc}
{Log.i}

{LogIt.i '"Begin Program"'}

/* Determine if the ticket exists */

FIND Ticket EXCLUSIVE-LOCK
WHERE Ticket.TicketSeq = pTicketSeq
NO-ERROR.

IF NOT AVAILABLE Ticket THEN DO:

  ASSIGN pError = {&NORECORD}.
  RETURN.

END.  /* IF NOT AVAILABLE Ticket */

/* Determine list of positions that can handle the ticket's assigned */
/* Status.                                                           */

{LogIt.i '"TicketStatusSeq = "' Ticket.TicketStatusSeq}

RUN api/ticket/Pos4Stat.p 
(INPUT Ticket.TicketStatusSeq,
 OUTPUT lListPositionSeq,
 OUTPUT lError).
 
{LogIt.i '"Positions from Pos4Stat" ' lListPositionSeq}
                
/* Determine if the ticket is assigned, and if the person assigned is */
/* a member of this list.                                             */

FIND TicketAssign OF Ticket EXCLUSIVE-LOCK NO-ERROR.

IF AVAILABLE TicketAssign THEN DO:

  FIND Employee OF TicketAssign NO-LOCK NO-ERROR.

  /* This should not happen, but cover for it */

  IF NOT AVAILABLE Employee THEN DO:

    ASSIGN pError = {&BADDATA}.
    RETURN.

  END. /* IF NOT AVAILABLE Employee */

  /* If the Employee's Position is in the list of positions that can */
  /* handle the ticket, then leave the ticket assigned as is.        */

  IF CAN-DO (lListPositionSeq, Employee.PositionSeq) THEN DO:

    ASSIGN 
    pEmployeeSeq = Employee.EmployeeSeq
    pError = {&NOERROR}.

    RETURN.

  END.  /* IF CAN-DO (lListPositionSeq, Employee.PositionSeq) */

END. /* IF AVAILABLE TicketAssign */

/* Ticket is free and open for assignment, determine the employees */
/* who are in the positions that can handle the ticket status.     */

RUN api/ticket/Emp4Pos.p
(INPUT lListPositionSeq,
 OUTPUT lListEmployeeSeq,
 OUTPUT pError).

{LogIt.i '"Emp4Pos returns "' lListEmployeeSeq}

/* Determine which employee has the least amount of tickets assigned to them */

{LogIt.i '"Going into CalcListTkt.p"'}

RUN api/ticket/CalcLstTkt.p
(INPUT lListEmployeeSeq,
 OUTPUT pEmployeeSeq,
 OUTPUT pError).

{LogIt.i '"CalcLstTkt.p sends back "' pEmployeeSeq}

/* In future versions, a check of the employee's vacation status should be */
/* added here.                                                             */




