/*
 * Written by Scott Auge scott_auge@yahoo.com sauge@amduus.com
 * Copyright (c) 2001 Amduus Information Works, Inc.  www.amduus.com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Amduus Information Works
 *      and its contributors.
 * 4. Neither the name of Amduus Information Works, Inc. nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY AMDUUS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AMDUUS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */



/* ModifyTicket.p
 * Written by Scott Auge
 *
 * Process business logic for ticket modification
 */

DEF INPUT PARAMETER pTicketSeq AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pUserSeq   AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pWorkLog   AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pStatusSeq AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER pError    AS CHARACTER NO-UNDO.

DEF VAR lNoteText      AS CHARACTER NO-UNDO.
DEF VAR pTicketNoteSeq AS CHARACTER NO-UNDO.

{api/Error.inc}
{Log.i}

{LogIt.i '"Begin Program"'}

FIND Ticket EXCLUSIVE-LOCK
WHERE Ticket.TicketSeq = pTicketSeq
NO-ERROR.

IF NOT AVAILABLE Ticket THEN DO:

  ASSIGN pError = {&NORECORD}.
  RETURN.

END.

FIND SystemUser NO-LOCK
WHERE SystemUser.UserSeq = pUserSeq
NO-ERROR.

IF NOT AVAILABLE Ticket THEN DO:

  ASSIGN pError = {&NORECORD}.
  RETURN.

END.

/* Make sure the status seq coming in is good for the ticket type (in case */
/* someone is muddling around with the URL instead of ModifyTicket.html!)  */
/* A blank StatusSeq means we are not interested in updating the ticket    */
/* status.                                                                 */

IF pStatusSeq <> "" THEN DO: 

  FIND ProblemType OF Ticket NO-LOCK.
  
  FIND TicketStatus OF ProblemType
  WHERE TicketStatus.TicketStatusSeq = pStatusSeq
  NO-LOCK NO-ERROR.
  
  IF NOT AVAILABLE TicketStatus THEN DO:

    ASSIGN pError = {&BADSTATUS}. 
    RETURN.
  
  END. /* Cannot find an appropriate status record */
 
  /* If the same status as previous, then do not modify the status!  */
  /* Otherwise make a note we are changing the status.  This is done */
  /* below in SetStatus.p cuz there is a lot of things to go on for  */
  /* that.                                                           */

  IF Ticket.TicketStatusSeq <> pStatusSeq THEN DO:  

    /* Add the status change to the work log */
  
    ASSIGN lNoteText = "Status: " + TicketStatus.Name
                     + " by " + SystemUser.FirstName + " " 
                     + SystemUser.LastName.
  
    RUN api/records/AddTicketNote.p (INPUT Ticket.TicketSeq,
                                  INPUT lNoteText,
                                  OUTPUT pTicketNoteSeq,
                                  OUTPUT pError).

  END. /* IF Ticket.TicketStatusSeq <> pStatusSeq */  

END. /* IF StatusSeq <> "" */

/* Add the note to the work log.  If no note, then of course, dont add */
/* a new work log entry!                                               */

IF pWorkLog <> "" THEN DO:

  ASSIGN lNoteText = "Updated: " + SystemUser.FirstName + " " 
                   + SystemUser.LastName
                   + "~r" + pWorkLog.

  RUN api/records/AddTicketNote.p (INPUT Ticket.TicketSeq,
                                INPUT lNoteText,
                                OUTPUT pTicketNoteSeq,
                                OUTPUT pError).

END. /* IF pWorkLog <> "" */

/* Determine if the ticket needs to be reassigned because of change */
/* of status.                                                       */

RUN api/ticket/SetStatus.p (INPUT Ticket.TicketSeq,
                            INPUT pStatusSeq,
                            OUTPUT pError).

{LogIt.i '"pError from SetStatus: "' pError}
{LogIt.i '"TicketStatus=: "' Ticket.TicketStatusSeq}

ASSIGN pError = {&NOERROR}.

