/*
 * Written by Scott Auge scott_auge@yahoo.com sauge@amduus.com
 * Copyright (c) 2001 Amduus Information Works, Inc.  www.amduus.com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Amduus Information Works
 *      and its contributors.
 * 4. Neither the name of Amduus Information Works, Inc. nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY AMDUUS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AMDUUS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */



/*
 * Register.p
 * Written by Scott Auge
 *
 * Perform a registration according to business rules.
 * NOTE THIS IS FOR REGISTRATION OF EXTERNAL USERS. SEE oper/Registration.p
 * FOR CREATION OF INTERNAL USERS.
 *
 */

DEF VAR RCSVersion AS CHARACTER INIT "$Header: /home/appl/srvexp/src/web/RCS/Register.p,v 1.3 2001/12/15 20:39:11 sauge Exp $" NO-UNDO.

DEF INPUT PARAMETER lCompanyName AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lUserID     AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lPassword1  AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lPassword2  AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lFirstName  AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lLastName   AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lStreet1    AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lStreet2    AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lApartment  AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lCity       AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lState      AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lZip        AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lPhone      AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lEmail      AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lMobile     AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lFax        AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER lPager      AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER pError     AS CHARACTER NO-UNDO.


DEF VAR lAddressSeq             AS CHARACTER NO-UNDO.
DEF VAR lUserSeq                AS CHARACTER NO-UNDO.

{api/Error.inc}
{Log.i}

{LogIt.i '"Begin Program"'}

/* Be assured the user passed in the same password!  This is because the */
/* web form might be using a Password input box which only shows stars   */
/* as the user types them.                                               */

IF lPassword1 <> lPassword2 THEN DO:

  ASSIGN pError = {&MISMATCHPASSWORD}.
  RETURN.

END.

/* Create the user.  Again, if there is a problem, pass the error back  */
/* to the calling program.  We do this before the address because the   */
/* api does some checking and might pass back an error which would have */
/* left a dangling address.                                             */

RUN api/records/CreateUser.p (lUserID,
                           lFirstName,
                           lLastName,
                           lPassword1,
                           lEmail,
    			   "C",
                           OUTPUT lUserSeq,
                           OUTPUT pError).

IF pError <> {&NOERROR} THEN
  RETURN.

/* Create an Address for the user.  If there is a problem, pass it back */
/* to the calling program.                                              */

RUN api/records/CreateAddress.p (lStreet1,
                                 lStreet2,
                                 lApartment,
                                 lCity,
                                 lState,
                                 lZip,
                                 OUTPUT lAddressSeq,
                                 OUTPUT pError).

IF pError <> {&NOERROR} THEN 
  RETURN.

/* Attach the address to the user.  This routine will pass back the */
/* result of the LAST API call.                                     */

RUN api/records/SetAddress.p (lUserSeq,
                           lAddressSeq,
                           OUTPUT pError).

/* Add some contact information to the User's record */

FIND SystemUser EXCLUSIVE-LOCK
where SystemUser.UserSeq = lUserSeq
NO-ERROR.

ASSIGN
SystemUser.CompanyName = lCompanyName
SystemUser.Mobile = lMobile
SystemUser.Fax   = lFax
SystemUser.Pager = lPager.

